import { useCallback, useEffect, useState } from 'react'
import EntryListItem from './EntryListItem';

function Recommend() {
  const [similarEntries, setSimilarEntries] = useState([]); // 関連記事を保存するstate変数
  const [interestEntries, setInterestEntries] = useState([]); // おすすめ記事を保存するstate変数
  const currentUrl = location.href;

  // 記事の取得
  const fetchEntries = useCallback(async () => {
    let json;

    try {
      const response = await fetch(`http://example.jp/powercmsx/plugins/SearchEstraier/app/pt-recommend-api.php?type=both&amp;limit=${limit}&amp;url=${currentUrl}`);
      json = await response.json();
    } catch (e) {
      return;
    }

    // 関連記事をstate変数にセット
    if (json.similar) {
      setSimilarEntries(json.similar);
    }

    // おすすめ記事をstate変数にセット
    if (json.interest) {
      setInterestEntries(json.interest);
    }
  }, [currentUrl]);

  // APIと同期させるためのReactフック
  useEffect(() => {
    fetchEntries(); // 記事の取得を実行
  }, [fetchEntries])

  return (
    <>
      {similarEntries.length > 0 && (
        <div id="similar-list-wrapper">
          <h2>関連性の高いページ</h2>
          <ul className="list-unstyled ml-0 recommend-list">
            {similarEntries.map((entry) => (
              <EntryListItem key={entry.object_id} entry={entry} />
            ))}
          </ul>
        </div>
      )}

      {interestEntries.length > 0 && (
        <div id="interest-list-wrapper">
          <h2>あなたへのお勧め</h2>
          <ul className="list-unstyled ml-0 recommend-list">
            {interestEntries.map((entry) => (
              <EntryListItem key={entry.object_id} entry={entry} />
            ))}
          </ul>
        </div>
      )}
    </>
  )
}

export default Recommend;
